/*
 * @(#)FormHLayout.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy.layout;

import java.awt.LayoutManager;
import java.util.StringTokenizer;

import com.jgoodies.forms.layout.FormLayout;

import chrriis.uihierarchy.UIHConfig;
import chrriis.uihierarchy.util.UnitParser;

/**
 * A form layout that is lazily created, using the UIH configuration. This
 * allows the use of units to determine the gaps. The form layout already
 * support units, but this class allows the use of the UIH units, which
 * definition may slightly differ.
 * @version 1.0 2005.02.06
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
public class FormHLayout implements HLayoutManager {

  protected String encodedColumnSpecs;
  protected String encodedRowSpecs;

  public FormHLayout(String encodedColumnSpecs, String encodedRowSpecs) {
    this.encodedColumnSpecs = encodedColumnSpecs;
    this.encodedRowSpecs = encodedRowSpecs;
  }

  public LayoutManager createLayout(UIHConfig uihConfig) {
    StringTokenizer st = new StringTokenizer(encodedColumnSpecs, ",:", true);
    StringBuffer sb = new StringBuffer();
    while(st.hasMoreTokens()) {
      String token = st.nextToken();
      if(",".equals(token) || ":".equals(token)) {
        sb.append(token);
      } else {
        try {
          sb.append(UnitParser.intPixelValue(uihConfig, token));
        } catch(Exception e) {
          sb.append(token);
        }
      }
    }
    encodedColumnSpecs = sb.toString();
    st = new StringTokenizer(encodedRowSpecs, ",:", true);
    sb = new StringBuffer();
    while(st.hasMoreTokens()) {
      String token = st.nextToken();
      if(",".equals(token) || ":".equals(token)) {
        sb.append(token);
      } else {
        try {
          sb.append(UnitParser.intPixelValue(uihConfig, token));
        } catch(Exception e) {
          sb.append(token);
        }
      }
    }
    encodedRowSpecs = sb.toString();
    return new FormLayout(encodedColumnSpecs, encodedRowSpecs);
  }


}
