/*
 * @(#)HashSet_1_1.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy.compatibility;

import java.util.Vector;

/**
 * The Java 1.1 implementation of HashSet.
 * @version 1.0 2004.01.11
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
class HashSet_1_1 implements Set {

  /** The vector. */
  protected Vector vector;

  /**
   * Constructs a new, empty set; the backing HashMap instance has default initial capacity (16) and load factor (0.75).
   */
  public HashSet_1_1() {
    vector = new Vector(16);
  }

  /**
   * Constructs a new, empty set; the backing HashMap instance has the specified initial capacity and default load factor, which is 0.75.
   * @param initialCapacity The initial capacity.
   */
  public HashSet_1_1(int initialCapacity) {
    vector = new Vector(initialCapacity);
  }

  /**
   * Returns true if this collection contains the specified element.
   * @param o The object to look for.
   * @return True if found.
   */
  public boolean contains(Object o) {
    return vector.contains(o);
  }

  /**
   * Adds the specified element to this set if it is not already present (optional operation).
   * @param o The object to add.
   * @return True if changed.
   */
  public boolean add(Object o) {
    if(vector.contains(o)) {
      return false;
    }
    vector.addElement(o);
    return true;
  }

  /**
   * Adds all of the elements in the specified collection to this set if they're not already present (optional operation).
   * @param c The collection.
   * @return True if changed.
   */
  public boolean addAll(Collection c) {
    Object[] objects = c.toArray();
    vector.ensureCapacity(c.size());
    boolean isChanged = false;
    for(int i=0; i<objects.length; i++) {
      isChanged |= add(objects[i]);
    }
    return isChanged;
  }

  /**
   * Returns the number of elements in this list.
   * @return The size.
   */
  public int size() {
    return vector.size();
  }

  /**
   * Returns an array containing all of the elements in this collection. 
   * @return The array.
   */
  public Object[] toArray() {
    Object[] objects = new Object[vector.size()];
    vector.copyInto(objects);
    return objects;
  }

  /**
   * Returns an array containing all of the elements in this collection; the runtime type of the returned array is that of the specified array.
   * @param a The array from which to get the type.
   * @return The array.
   */
  public Object[] toArray(Object[] a) {
    int elementCount = size();
    Object[] elementData = toArray();
    if (a.length < elementCount) {
      a = (Object[])java.lang.reflect.Array.newInstance(a.getClass().getComponentType(), elementCount);
    }
    System.arraycopy(elementData, 0, a, 0, elementCount);
    if (a.length > elementCount) {
      a[elementCount] = null;
    }
    return a;
  }

  /**
   * Removes the first occurrence in this list of the specified element (optional operation). 
   * @param o The element to remove.
   * @return True if the element was present.
   */
  public boolean remove(Object o) {
    return vector.removeElement(o);
  }

  /**
   * Removes all this collection's elements that are also contained in the specified collection (optional operation).
   * @param c The collection of elements to remove.
   * @return True if the collection was affected by this operation.
   */
  public boolean removeAll(Collection c) {
    Object[] objects = c.toArray();
    boolean isChanged = false;
    for(int i=0; i<objects.length; i++) {
      isChanged |= remove(objects[i]);
    }
    return isChanged;
  }

  /**
   * Returns true if this list contains no elements.
   * @return True if this list is empty.
   */
  public boolean isEmpty() {
    return vector.isEmpty();
  }

}
