/*
 * @(#)HLeaf.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy;

import java.awt.Component;
import chrriis.uihierarchy.compatibility.List;

/**
 * A leaf in the hierarchy.
 * @version 2.0 2003.11.02
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
public class HLeaf extends HLevel {

  /**
   * Construct a leaf.
   * @param uihConfig The configuration.
   * @param parent The hierarchy parent component of this one.
   * @param component The component.
   */
  protected HLeaf(UIHConfig uihConfig, HParentLevel parent, Object component) {
    super(uihConfig, parent, component);
  }

  /**
   * Use the specified constraints.
   * @param constraints The constraints to use.
   * @return The hierarchy leaf.
   */
  public HLeaf constrain(Object constraints) {
    constrain_(constraints);
    return this;
  }

  /**
   * Get the component at this hierarchy level.
   * @return The component.
   */
  public Component getComponent() {
    return super.getComponent();
  }

  /**
   * Map the given name to the current component. The mapping definitions are
   * kept in the <code>UIHConfig</code> configuration.
   * @param name The name of the component.
   * @return The hierarchy leaf.
   * @see chrriis.uihierarchy.UIHConfig
   */
  public HLeaf map(String name) {
    map_(name);
    return this;
  }

  /**
   * Add the level to the debugging process, using default parameters.
   */
  public HLeaf debug() {
    debug(null);
    return this;
  }

  /**
   * Add the level to the debugging process.
   * @param parameters The parameters to use to debug, which can actually be a
   * debugger to use.
   */
  public HLeaf debug(Object parameters) {
    debug_(parameters);
    return this;
  }

  /**
   * Get a String representation of the hierarchy level.
   * @see java.lang.Object#toString()
   */
  public String toString() {
    String mapList = "";
    List keyList = getConfig().getMapList(this);
    if(!keyList.isEmpty()) {
      mapList = " [Map:";
      for(int i=0; i<keyList.size(); i++) {
        mapList += (i==0? " ": ", ") + keyList.get(i);
      }
      mapList += "]";
    }
    return "- "
    + getClassName(getComponent().getClass())
    + (getConstraints() != null? " [Cons: " + getConstraints() + "]": "")
    + mapList
    ;
  }

}
