/*
 * @(#)HashSet.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy.compatibility;

/**
 * The HashSet compatible version.
 * @version 1.0 2004.01.11
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
public class HashSet implements Set {

  /** The hash set. */
  protected Object hashSet;

  /**
   * Constructs a new, empty set; the backing HashMap instance has default initial capacity (16) and load factor (0.75).
   */
  public HashSet() {
    if(Compatibility.isJava1_1()) {
      hashSet = new HashSet_1_1();
    } else {
      hashSet = new java.util.HashSet();
    }
  }

  /**
   * Constructs a new, empty set; the backing HashMap instance has the specified initial capacity and default load factor, which is 0.75.
   * @param initialCapacity The initial capacity.
   */
  public HashSet(int initialCapacity) {
    if(Compatibility.isJava1_1()) {
      hashSet = new HashSet_1_1(initialCapacity);
    } else {
      hashSet = new java.util.HashSet(initialCapacity);
    }
  }

  /**
   * Returns an array containing all of the elements in this collection. 
   * @return The array.
   */
  public Object[] toArray() {
    if(Compatibility.isJava1_1()) {
      return ((HashSet_1_1)hashSet).toArray();
    }
    return ((java.util.HashSet)hashSet).toArray();
  }

  /**
   * Returns an array containing all of the elements in this collection; the runtime type of the returned array is that of the specified array.
   * @param a The array from which to get the type.
   * @return The array.
   */
  public Object[] toArray(Object[] a) {
    if(Compatibility.isJava1_1()) {
      return ((HashSet_1_1)hashSet).toArray(a);
    }
    return ((java.util.HashSet)hashSet).toArray(a);
  }

  /**
   * Returns true if this collection contains the specified element.
   * @param o The object to look for.
   * @return True if found.
   */
  public boolean contains(Object o) {
    if(Compatibility.isJava1_1()) {
      return ((HashSet_1_1)hashSet).contains(o);
    }
    return ((java.util.HashSet)hashSet).contains(o);
  }

  /**
   * Adds the specified element to this set if it is not already present (optional operation).
   * @param o The object to add.
   * @return True if changed.
   */
  public boolean add(Object o) {
    if(Compatibility.isJava1_1()) {
      return ((HashSet_1_1)hashSet).add(o);
    }
    return ((java.util.HashSet)hashSet).add(o);
  }

  /**
   * Adds all of the elements in the specified collection to this set if they're not already present (optional operation).
   * @param c The collection.
   * @return True if changed.
   */
  public boolean addAll(Collection c) {
    if(Compatibility.isJava1_1()) {
      return ((HashSet_1_1)hashSet).addAll(c);
    }
    Object[] objects = c.toArray();
    boolean isChanged = false;
    for(int i=0; i<objects.length; i++) {
      isChanged |= ((java.util.HashSet)hashSet).add(objects[i]);
    }
    return isChanged;
  }

  /**
   * Returns the number of elements in this list.
   * @return The size.
   */
  public int size() {
    if(Compatibility.isJava1_1()) {
      return ((HashSet_1_1)hashSet).size();
    }
    return ((java.util.HashSet)hashSet).size();
  }

  /**
   * Removes the first occurrence in this list of the specified element (optional operation). 
   * @param o The element to remove.
   * @return True if the element was present.
   */
  public boolean remove(Object o) {
    if(Compatibility.isJava1_1()) {
      return ((HashSet_1_1)hashSet).remove(o);
    }
    return ((java.util.HashSet)hashSet).remove(o);
  }

  /**
   * Removes all this collection's elements that are also contained in the specified collection (optional operation).
   * @param c The collection of elements to remove.
   * @return True if the collection was affected by this operation.
   */
  public boolean removeAll(Collection c) {
    if(Compatibility.isJava1_1()) {
      return ((HashSet_1_1)hashSet).removeAll(c);
    }
    Object[] objects = c.toArray();
    boolean isChanged = false;
    for(int i=0; i<objects.length; i++) {
      isChanged |= ((java.util.HashSet)hashSet).remove(objects[i]);
    }
    return isChanged;
  }

  /**
   * Returns true if this list contains no elements.
   * @return True if this list is empty.
   */
  public boolean isEmpty() {
    if(Compatibility.isJava1_1()) {
      return ((HashSet_1_1)hashSet).isEmpty();
    }
    return ((java.util.HashSet)hashSet).isEmpty();
  }

}
