/*
 * @(#)Debugger.java
 * 
 * Christopher Deckers (chrriis@brainlex.com)
 * http://chrriis.brainlex.com
 * 
 * See the file "LICENSE.txt" for information on usage and redistribution of
 * this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */
package chrriis.uihierarchy.debug;

import java.awt.Color;
import java.awt.Component;

import javax.swing.JComponent;

import chrriis.uihierarchy.Accessor;
import chrriis.uihierarchy.compatibility.Compatibility;

/**
 * The debugger of levels.
 * @version 1.0 2004.01.11
 * @author Christopher Deckers (chrriis@brainlex.com)
 */
public class Debugger {

  /**
   * Debug some hierarchy components.
   * @param accessor The accessors of the components to debug.
   * @param parameters The parameters to use to debug. The recognized parameters
   * for this debugger are a String representing a color. The String is either
   * "random" for a random color, or one of the following: "black", "blue",
   * "cyan", "green", "magenta", "orange", "pink", "red", "white" and "yellow".
   * The default, when the parameters are null, is "red".
   */
  public void debug(Accessor accessor, Object parameters) {
    boolean isRandom = false;
    Color color = null;
    if(parameters != null) {
      if(parameters instanceof String) {
        String param = ((String)parameters).toLowerCase().trim();
        if(param.equals("random")) {
          isRandom = true;
        } else {
          try {
            color = ((Color)Color.class.getField(((String)parameters).toLowerCase().trim()).get(null));
          } catch(Exception e) {
            throw new IllegalArgumentException("The parameters must be a possible color!");
          }
        }
      } else {
        throw new IllegalArgumentException("Cannot handle parameters that are not Strings!");
      }
    }
    if(!isRandom && color == null) {
      color = Color.red;
    }
    Component[] components = accessor.getComponents();
    for(int i=0; i<components.length; i++) {
      Component component = components[i];
      if(Compatibility.isSwingPresent() && component instanceof JComponent) {
        ((JComponent)component).setOpaque(true);
      }
      if(isRandom) {
        color = new Color((float)Math.random(), (float)Math.random(), (float)Math.random());
      }
      component.setBackground(color);
    }
  }

}
